# 结巴——jieba 中文版

#### 介绍
草蟒中文分词库——结巴（jieba中文版）

#### 安装

`python -m pip install -U grasspy-jieba`

#### 使用说明

```python
>>> 导入 结巴
>>> 结巴.分词列表('我来到了中国科学技术大学')
['我', '来到', '了', '中国', '科学技术', '大学']
```

更多信息请参阅《草蟒（Python 中文版）入门指南》中的分词相关示例
